@@ -253,8 +253,12 @@ class JyInterface(object):
                                                                  passphrase=self.passphrase,
                                                                  symbols=symbol, 
                                                                  direction=direction,
-                                                                 amount=amount))
-        return float(response.message)  # 是否成功; 0:成功,1:失败
+                                                                 amount=str(amount)))
+        if response.message == "true":
+            output = 0
+        else:
+            output = 1
+        return output # 是否成功; 0:成功,1:失败
 
     def run_(self):
         """let subclass inherit"""
